@@ -21,14 +21,11 @@
 #include <QVBoxLayout>
 
 // KDE
-#include <kaboutdata.h>
-#include <kbuildsycocaprogressdialog.h>
-#include <klocalizedstring.h>
-
-#include <kservicetypeprofile.h>
-#include <ksycoca.h>
-
-#include <kwindowsystem.h>
+#include <KAboutData>
+#include <KBuildSycocaProgressDialog>
+#include <KLocalizedString>
+#include <KSycoca>
+#include <KWindowSystem>
 
 // Local
 #include "filetypedetails.h"
@@ -111,9 +108,6 @@ void FileTypeDialog::slotDatabaseChanged()
 int main(int argc, char **argv)
 {
     QApplication app(argc, argv);
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    app.setAttribute(Qt::AA_UseHighDpiPixmaps, true);
-#endif
     QApplication::setWindowIcon(QIcon::fromTheme(QStringLiteral("preferences-desktop-filetype-association")));
 
     KAboutData aboutData(QStringLiteral("keditfiletype"),
@@ -199,3 +193,5 @@ int main(int argc, char **argv)
 
     return app.exec();
 }
+
+#include "moc_keditfiletype.cpp"
